@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001 Marc Alexander Lehmann <pcg@goof.com>
+ * Copyright (c) 2001-2005 Marc Alexander Lehmann <schmorp@schmorp.de>
  * 
  * Redistribution and use in source and binary forms, with or without modifica-
  * tion, are permitted provided that the following conditions are met:
@@ -33,15 +33,21 @@
  * build your own process abstraction using it or - better - just use GNU
  * Portable Threads, http://www.gnu.org/software/pth/.
  *
- * VERSION: 0.1
  */
 
 #ifndef CORO_H
 #define CORO_H
 
+#define CORO_VERSION 2
+
+/*
+ * Changes since API version 1:
+ * replaced bogus -DCORO_LOOSE with gramatically more correct -DCORO_LOSER
+ */
+
 /*
  * This library consists of only three files
- * coro.h, coro.c and LICENSE
+ * coro.h, coro.c and LICENSE (and optionally README)
  *
  * It implements what is known as coroutines, in a hopefully
  * portable way. At the moment you have to define which kind
@@ -67,7 +73,7 @@
  *    Old GNU/Linux systems (<= glibc-2.1) work with this implementation
  *    (very fast).
  *
- * -DCORO_LOOSE
+ * -DCORO_LOSER
  *
  *    Microsoft's highly proprietary platform doesn't support sigaltstack, and
  *    this automatically selects a suitable workaround for this platform.
@@ -78,7 +84,7 @@
  *    SGI's version of Microsoft's NT ;)
  *
  * If you define neither of these symbols, coro.h will try to autodetect
- * the model.  This currently works for CORO_LOOSE only. For the other
+ * the model.  This currently works for CORO_LOSER only. For the other
  * alternatives you should check (e.g. using autoconf) and define the
  * following symbols: HAVE_UCONTEXT_H / HAVE_SETJMP_H / HAVE_SIGALTSTACK.
  */
@@ -120,11 +126,11 @@ void coro_transfer(coro_context *prev, coro_context *next);
 
 /*****************************************************************************/
 
-#if !defined(CORO_LOOSE) && !defined(CORO_UCONTEXT) \
+#if !defined(CORO_LOSER) && !defined(CORO_UCONTEXT) \
     && !defined(CORO_SJLJ) && !defined(CORO_LINUX) \
     && !defined(CORO_IRIX)
 # if defined(WINDOWS)
-#  define CORO_LOOSE 1 /* you don't win with windoze */
+#  define CORO_LOSER 1 /* you don't win with windoze */
 # elif defined(__linux) && defined(__x86)
 # elif defined(HAVE_UCONTEXT_H)
 #  define CORO_UCONTEXT 1
@@ -147,9 +153,9 @@ struct coro_context {
 
 #define coro_transfer(p,n) swapcontext (&((p)->uc), &((n)->uc))
 
-#elif CORO_SJLJ || CORO_LOOSE || CORO_LINUX || CORO_IRIX
+#elif CORO_SJLJ || CORO_LOSER || CORO_LINUX || CORO_IRIX
 
-#ifdef CORO_LINUX
+#if defined(CORO_LINUX) && !defined(_GNU_SOURCE)
 # define _GNU_SOURCE // for linux libc
 #endif
 
